"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StandardDeadLetterQueue = void 0;
const aws_cdk_lib_1 = require("aws-cdk-lib");
const aws_cloudwatch_1 = require("aws-cdk-lib/aws-cloudwatch");
const aws_sqs_1 = require("aws-cdk-lib/aws-sqs");
/**
 * Standard dead letter queue implementation with an alarm that triggers when messages are received.
 */
class StandardDeadLetterQueue extends aws_sqs_1.Queue {
    constructor(scope, id, props) {
        var _a, _b, _c, _d, _e, _f;
        super(scope, id, {
            queueName: props.queueName,
            retentionPeriod: (_a = props.retentionPeriod) !== null && _a !== void 0 ? _a : aws_cdk_lib_1.Duration.minutes(14),
            encryption: (_b = props.encryption) !== null && _b !== void 0 ? _b : aws_sqs_1.QueueEncryption.SQS_MANAGED,
            encryptionMasterKey: props.encryptionMasterKey,
            dataKeyReuse: props.dataKeyReuse,
            removalPolicy: (_c = props.removalPolicy) !== null && _c !== void 0 ? _c : aws_cdk_lib_1.RemovalPolicy.DESTROY,
            enforceSSL: (_d = props.enforceSSL) !== null && _d !== void 0 ? _d : true,
            receiveMessageWaitTime: (_e = props.receiveMessageWaitTime) !== null && _e !== void 0 ? _e : aws_cdk_lib_1.Duration.seconds(20),
        });
        this.alarm = new aws_cloudwatch_1.Alarm(this, 'Alarm', {
            metric: this.metricApproximateNumberOfMessagesVisible(),
            threshold: (_f = props.alarmThreshold) !== null && _f !== void 0 ? _f : 1,
            evaluationPeriods: 1,
            treatMissingData: aws_cloudwatch_1.TreatMissingData.IGNORE,
            comparisonOperator: aws_cloudwatch_1.ComparisonOperator.GREATER_THAN_OR_EQUAL_TO_THRESHOLD,
        });
    }
}
exports.StandardDeadLetterQueue = StandardDeadLetterQueue;
//# sourceMappingURL=standard-dead-letter-queue.js.map